@@ -412,7 +412,10 @@ def parse_args(detector_classes, printer_classes):  # pylint: disable=too-many-s
     )
 
     group_misc.add_argument(
-        "--markdown-root", help="URL for markdown generation", action="store", default="",
+        "--markdown-root",
+        help="URL for markdown generation",
+        action="store",
+        default="",
     )
 
     group_misc.add_argument(
@@ -447,7 +450,10 @@ def parse_args(detector_classes, printer_classes):  # pylint: disable=too-many-s
     )
 
     group_misc.add_argument(
-        "--solc-ast", help="Provide the contract as a json AST", action="store_true", default=False,
+        "--solc-ast",
+        help="Provide the contract as a json AST",
+        action="store_true",
+        default=False,
     )
 
     group_misc.add_argument(
@@ -500,7 +506,10 @@ def parse_args(detector_classes, printer_classes):  # pylint: disable=too-many-s
     )
 
     parser.add_argument(
-        "--perf", help=argparse.SUPPRESS, action="store_true", default=False,
+        "--perf",
+        help=argparse.SUPPRESS,
+        action="store_true",
+        default=False,
     )
 
     # if the json is splitted in different files
