@@ -136,7 +136,9 @@ def is_tainted_ssa(variable, context, only_unprotected=False, ignore_generic_tai
 
 
 def get_dependencies(
-    variable: Variable, context: Union[Contract, Function], only_unprotected: bool = False,
+    variable: Variable,
+    context: Union[Contract, Function],
+    only_unprotected: bool = False,
 ) -> Set[Variable]:
     """
     Return the variables for which `variable` depends on.
@@ -171,7 +173,9 @@ def get_all_dependencies(
 
 
 def get_dependencies_ssa(
-    variable: Variable, context: Union[Contract, Function], only_unprotected: bool = False,
+    variable: Variable,
+    context: Union[Contract, Function],
+    only_unprotected: bool = False,
 ) -> Set[Variable]:
     """
     Return the variables for which `variable` depends on (SSA version).
@@ -382,7 +386,16 @@ def convert_variable_to_non_ssa(v):
         return v.non_ssa_version
     assert isinstance(
         v,
-        (Constant, SolidityVariable, Contract, Enum, SolidityFunction, Structure, Function, Type,),
+        (
+            Constant,
+            SolidityVariable,
+            Contract,
+            Enum,
+            SolidityFunction,
+            Structure,
+            Function,
+            Type,
+        ),
     )
     return v
 
