@@ -43,7 +43,6 @@ if TYPE_CHECKING:
     from slither.core.expressions.expression import Expression
     from slither.slithir.operations import Operation
     from slither.slither import Slither
-    from slither.core.cfg.node import NodeType
     from slither.core.slither_core import SlitherCore
 
 LOGGER = logging.getLogger("Function")
@@ -52,7 +51,10 @@ ReacheableNode = namedtuple("ReacheableNode", ["node", "ir"])
 
 class ModifierStatements:
     def __init__(
-        self, modifier: Union["Contract", "Function"], entry_point: "Node", nodes: List["Node"],
+        self,
+        modifier: Union["Contract", "Function"],
+        entry_point: "Node",
+        nodes: List["Node"],
     ):
         self._modifier = modifier
         self._entry_point = entry_point
@@ -125,10 +127,10 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
         self._slithir_variables: Set["SlithIRVariable"] = set()
         self._parameters: List["LocalVariable"] = []
         self._parameters_ssa: List["LocalIRVariable"] = []
-        self._parameters_src: Optional[SourceMapping] = None
+        self._parameters_src: SourceMapping = SourceMapping()
         self._returns: List["LocalVariable"] = []
         self._returns_ssa: List["LocalIRVariable"] = []
-        self._returns_src: Optional[SourceMapping] = None
+        self._returns_src: SourceMapping = SourceMapping()
         self._return_values: Optional[List["SlithIRVariable"]] = None
         self._return_values_ssa: Optional[List["SlithIRVariable"]] = None
         self._vars_read: List["Variable"] = []
@@ -299,17 +301,18 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
 
     def can_send_eth(self) -> bool:
         """
-        Check if the function can send eth
+        Check if the function or any internal (not external) functions called by it can send eth
         :return bool:
         """
         from slither.slithir.operations import Call
 
         if self._can_send_eth is None:
+            self._can_send_eth = False
             for ir in self.all_slithir_operations():
                 if isinstance(ir, Call) and ir.can_send_eth():
                     self._can_send_eth = True
                     return True
-        return self._can_reenter
+        return self._can_send_eth
 
     @property
     def slither(self) -> "SlitherCore":
@@ -567,6 +570,9 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
     def add_parameter_ssa(self, var: "LocalIRVariable"):
         self._parameters_ssa.append(var)
 
+    def parameters_src(self) -> SourceMapping:
+        return self._parameters_src
+
     # endregion
     ###################################################################################
     ###################################################################################
@@ -585,6 +591,9 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
             return [r.type for r in returns]
         return None
 
+    def returns_src(self) -> SourceMapping:
+        return self._returns_src
+
     @property
     def type(self) -> Optional[List[Type]]:
         """
@@ -1147,7 +1156,9 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
 
     @staticmethod
     def _explore_func_conditional(
-        func: "Function", f: Callable[["Node"], List[SolidityVariable]], include_loop: bool,
+        func: "Function",
+        f: Callable[["Node"], List[SolidityVariable]],
+        include_loop: bool,
     ):
         ret = [f(n) for n in func.nodes if n.is_conditional(include_loop)]
         return [item for sublist in ret for item in sublist]
@@ -1594,10 +1605,14 @@ class Function(metaclass=ABCMeta):  # pylint: disable=too-many-public-methods
 
         return ret
 
-    def get_last_ssa_state_variables_instances(self,) -> Dict[str, Set["SlithIRVariable"]]:
+    def get_last_ssa_state_variables_instances(
+        self,
+    ) -> Dict[str, Set["SlithIRVariable"]]:
         return self._get_last_ssa_variable_instances(target_state=True, target_local=False)
 
-    def get_last_ssa_local_variables_instances(self,) -> Dict[str, Set["SlithIRVariable"]]:
+    def get_last_ssa_local_variables_instances(
+        self,
+    ) -> Dict[str, Set["SlithIRVariable"]]:
         return self._get_last_ssa_variable_instances(target_state=False, target_local=True)
 
     @staticmethod
