@@ -30,7 +30,7 @@ contract Uninitialized is Owner{
 ```
 Bob calls `transfer`. As a result, all Ether is sent to the address `0x0` and is lost."""
 
-    WIKI_RECOMMENDATION = "Initialize all the variables. If a variable is meant to be initialized to zero, explicitly set it to zero."
+    WIKI_RECOMMENDATION = "Initialize all the variables. If a variable is meant to be initialized to zero, explicitly set it to zero to improve code readability."
 
     key = "UNINITIALIZEDLOCAL"
 
