@@ -22,10 +22,10 @@ def custom_format(slither, result):
                     result,
                     element["source_mapping"]["filename_absolute"],
                     int(
-                        function.parameters_src.source_mapping["start"]
-                        + function.parameters_src.source_mapping["length"]
+                        function.parameters_src().source_mapping["start"]
+                        + function.parameters_src().source_mapping["length"]
                     ),
-                    int(function.returns_src.source_mapping["start"]),
+                    int(function.returns_src().source_mapping["start"]),
                 )
 
 
