@@ -17,8 +17,8 @@ def custom_format(slither, result):
                     slither,
                     result,
                     element["source_mapping"]["filename_absolute"],
-                    int(function.parameters_src.source_mapping["start"]),
-                    int(function.returns_src.source_mapping["start"]),
+                    int(function.parameters_src().source_mapping["start"]),
+                    int(function.returns_src().source_mapping["start"]),
                 )
 
 
