@@ -26,7 +26,6 @@ from slither.utils.expression_manipulations import SplitTernaryExpression
 from slither.visitors.expression.export_values import ExportValues
 from slither.visitors.expression.has_conditional import HasConditional
 from slither.solc_parsing.exceptions import ParsingError
-from slither.core.source_mapping.source_mapping import SourceMapping
 
 if TYPE_CHECKING:
     from slither.core.expressions.expression import Expression
@@ -85,9 +84,6 @@ class FunctionSolc:
 
         self._analyze_type()
 
-        self.parameters_src = SourceMapping()
-        self.returns_src = SourceMapping()
-
         self._node_to_nodesolc: Dict[Node, NodeSolc] = dict()
         self._node_to_yulobject: Dict[Node, YulBlock] = dict()
 
@@ -454,7 +450,10 @@ class FunctionSolc:
                 return key in attributes and not attributes[key]
 
             if attributes and any(
-                map(has_hint, ["condition", "initializationExpression", "loopExpression"],)
+                map(
+                    has_hint,
+                    ["condition", "initializationExpression", "loopExpression"],
+                )
             ):
                 # if we have attribute hints, rely on those
 
@@ -602,7 +601,8 @@ class FunctionSolc:
             link_underlying_nodes(node_startDoWhile, node_condition)
         else:
             link_nodes(
-                node_startDoWhile.underlying_node, node_condition.underlying_node.sons[0],
+                node_startDoWhile.underlying_node,
+                node_condition.underlying_node.sons[0],
             )
         link_underlying_nodes(statement, node_condition)
         link_underlying_nodes(node_condition, node_endDoWhile)
@@ -895,7 +895,7 @@ class FunctionSolc:
             return_node = self._new_node(NodeType.RETURN, statement["src"])
             link_underlying_nodes(node, return_node)
             if self.is_compact_ast:
-                if statement["expression"]:
+                if statement.get("expression", None):
                     return_node.add_unparsed_expression(statement["expression"])
             else:
                 if (
@@ -1085,7 +1085,7 @@ class FunctionSolc:
     def _parse_params(self, params: Dict):
         assert params[self.get_key()] == "ParameterList"
 
-        self.parameters_src.set_offset(params["src"], self._function.slither)
+        self._function.parameters_src().set_offset(params["src"], self._function.slither)
 
         if self.is_compact_ast:
             params = params["parameters"]
@@ -1101,7 +1101,7 @@ class FunctionSolc:
 
         assert returns[self.get_key()] == "ParameterList"
 
-        self.returns_src.set_offset(returns["src"], self._function.slither)
+        self._function.returns_src().set_offset(returns["src"], self._function.slither)
 
         if self.is_compact_ast:
             returns = returns["parameters"]
