@@ -410,7 +410,9 @@ Please rename it, this name is reserved for Slither's internals"""
                 contracts_to_be_analyzed += [contract]
 
     def _analyze_first_part(
-        self, contracts_to_be_analyzed: List[ContractSolc], libraries: List[ContractSolc],
+        self,
+        contracts_to_be_analyzed: List[ContractSolc],
+        libraries: List[ContractSolc],
     ):
         for lib in libraries:
             self._parse_struct_var_modifiers_functions(lib)
@@ -435,7 +437,9 @@ Please rename it, this name is reserved for Slither's internals"""
                 contracts_to_be_analyzed += [contract]
 
     def _analyze_second_part(
-        self, contracts_to_be_analyzed: List[ContractSolc], libraries: List[ContractSolc],
+        self,
+        contracts_to_be_analyzed: List[ContractSolc],
+        libraries: List[ContractSolc],
     ):
         for lib in libraries:
             self._analyze_struct_events(lib)
@@ -462,7 +466,9 @@ Please rename it, this name is reserved for Slither's internals"""
                 contracts_to_be_analyzed += [contract]
 
     def _analyze_third_part(
-        self, contracts_to_be_analyzed: List[ContractSolc], libraries: List[ContractSolc],
+        self,
+        contracts_to_be_analyzed: List[ContractSolc],
+        libraries: List[ContractSolc],
     ):
         for lib in libraries:
             self._analyze_variables_modifiers_functions(lib)
