@@ -165,7 +165,10 @@ class YulScope(metaclass=abc.ABCMeta):
         self._yul_local_functions.append(func)
 
     def get_yul_local_function_from_name(self, func_name):
-        return next((v for v in self._yul_local_functions if v.underlying.name == func_name), None,)
+        return next(
+            (v for v in self._yul_local_functions if v.underlying.name == func_name),
+            None,
+        )
 
 
 class YulLocalVariable:  # pylint: disable=too-few-public-methods
@@ -457,7 +460,11 @@ def convert_yul_switch(root: YulScope, parent: YulNode, ast: Dict) -> YulNode:
                     "name": "eq",
                 },
                 "arguments": [
-                    {"nodeType": "YulIdentifier", "src": case_ast["src"], "name": switch_expr_var,},
+                    {
+                        "nodeType": "YulIdentifier",
+                        "src": case_ast["src"],
+                        "name": switch_expr_var,
+                    },
                     value_ast,
                 ],
             },
@@ -640,7 +647,16 @@ def parse_yul_function_call(root: YulScope, node: YulNode, ast: Dict) -> Optiona
         if name in unary_ops:
             return UnaryOperation(args[0], unary_ops[name])
 
-        ident = Identifier(SolidityFunction(format_function_descriptor(ident.value.name)))
+        if name == "stop":
+            name = "return"
+            ident = Identifier(SolidityFunction(format_function_descriptor(name)))
+            args = [
+                Literal("0", ElementaryType("uint256")),
+                Literal("0", ElementaryType("uint256")),
+            ]
+
+        else:
+            ident = Identifier(SolidityFunction(format_function_descriptor(ident.value.name)))
 
     if isinstance(ident.value, Function):
         return CallExpression(ident, args, vars_to_typestr(ident.value.returns))
