@@ -22,18 +22,23 @@ def parse_args():
     :return: Returns the arguments for the program.
     """
     parser = argparse.ArgumentParser(
-        description="slither-kspec-coverage", usage="slither-kspec-coverage contract.sol kspec.md",
+        description="slither-kspec-coverage",
+        usage="slither-kspec-coverage contract.sol kspec.md",
     )
 
     parser.add_argument(
         "contract", help="The filename of the contract or truffle directory to analyze."
     )
     parser.add_argument(
-        "kspec", help="The filename of the Klab spec markdown for the analyzed contract(s)",
+        "kspec",
+        help="The filename of the Klab spec markdown for the analyzed contract(s)",
     )
 
     parser.add_argument(
-        "--version", help="displays the current version", version="0.1.0", action="version",
+        "--version",
+        help="displays the current version",
+        version="0.1.0",
+        action="version",
     )
     parser.add_argument(
         "--json",
